@@ -1,6 +1,7 @@
 /*
  * <one line to give the library's name and an idea of what it does.>
  * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
+ * Copyright (C) 2016  Christoph Cullmann <cullmann@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,6 +23,7 @@
 #define ODFEXTRACTORTEST_H
 
 #include <QObject>
+#include <QMimeDatabase>
 
 class OdfExtractorTest : public QObject
 {
@@ -35,6 +37,11 @@ private Q_SLOTS:
 
     void testPresentation();
 
+    void testTextMissingMetaNoCrash();
+    void testTextMissingContentNoCrash();
+
+private:
+    QMimeDatabase mimeDb;
 };
 
 #endif // ODFEXTRACTORTEST_H
