@@ -29,14 +29,16 @@ namespace KFileMetaData
 class TagLibExtractor : public ExtractorPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin")
+    Q_PLUGIN_METADATA(IID "org.kde.kf5.kfilemetadata.ExtractorPlugin"
+                      FILE "taglibextractor.json")
     Q_INTERFACES(KFileMetaData::ExtractorPlugin)
 
 public:
     explicit TagLibExtractor(QObject* parent = nullptr);
 
-    void extract(ExtractionResult* result) Q_DECL_OVERRIDE;
-    QStringList mimetypes() const Q_DECL_OVERRIDE;
+    void extract(ExtractionResult* result) override;
+    QStringList mimetypes() const override;
+
 };
 
 }
